]> sigrok.org Git - pulseview.git/commitdiff
Cosmetics, typos.
authorUwe Hermann <redacted>
Mon, 18 Feb 2013 23:56:19 +0000 (00:56 +0100)
committerUwe Hermann <redacted>
Wed, 20 Feb 2013 09:36:46 +0000 (10:36 +0100)
main.cpp

index 54a69fd75550eb3485861bd471d27f6e2d6497a7..ba8e787069be74066f510c3e1ab28a3459a8401a 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -36,6 +36,7 @@ extern "C" {
 
 // Global pointer to our QApplication
 QApplication *g_app = NULL;
 
 // Global pointer to our QApplication
 QApplication *g_app = NULL;
+
 void usage()
 {
        fprintf(stderr,
 void usage()
 {
        fprintf(stderr,
@@ -49,13 +50,13 @@ void usage()
 }
 
 /*
 }
 
 /*
* SIGINT handler (likely recieved Ctrl-C from terminal)
  */
  */
-void sigint(int param)
+void sigint_handler(int param)
 {
 {
-       (void) param;
+       (void)param;
 
 
-       qDebug("pv: Recieved SIGINT");
+       qDebug("Received SIGINT.");
 
        if (g_app)
                g_app->quit();
 
        if (g_app)
                g_app->quit();
@@ -67,7 +68,7 @@ int main(int argc, char *argv[])
        struct sr_context *sr_ctx = NULL;
 
        // Register a SIGINT handler
        struct sr_context *sr_ctx = NULL;
 
        // Register a SIGINT handler
-       signal (SIGINT, sigint);
+       signal(SIGINT, sigint_handler);
 
        QApplication a(argc, argv);
        // Now we have an application to populate our global pointer
@@ -49,13 +50,13 @@ void usage()
 
 /*
- * SIGINT handler (likely recieved Ctrl-C from terminal)
+ * SIGINT handler (likely received Ctrl-C from terminal)
  */
  */
 
        QApplication a(argc, argv);
        // Now we have an application to populate our global pointer